"""JSON type aliases."""
from typing import Any, Dict, List, Union

JSON = Union[None, bool, int, float, str, List[Any], Dict[str, Any]]

JSONObject = Dict[str, JSON]

JSONObjectList = List[JSONObject]
